@@ -97,6 +97,8 @@ class SettingsDialog:
         builder.connect_signals(self)
         self.__controller = Gtk.EventControllerKey.new(self.__settings_dialog)
         self.__controller.connect("key-released", self.__on_key_released)
+        if App().system_supports_color_schemes:
+            builder.get_object("dark_row").hide()
 
     def show(self):
         """
@@ -149,6 +151,10 @@ class SettingsDialog:
         setting = widget.get_name()
         value = widget.get_active()
         App().settings.set_enum(setting, value)
+        if setting == "replay-gain":
+            for plugin in App().player.plugins:
+                plugin.build_audiofilter()
+            App().player.reload_track()
 
     def _on_clean_artwork_cache_clicked(self, button):
         """
