@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -12,7 +12,7 @@
 
 from gi.repository import Gtk, GLib, Handy
 
-from lollypop.define import App, ScanType
+from lollypop.define import App, ScanType, ArtSize
 from lollypop.container import Container
 from lollypop.toolbar import Toolbar
 from lollypop.utils import emit_signal
@@ -43,6 +43,7 @@ class Window(Handy.ApplicationWindow, SignalsHelper):
         self.connect("window-state-event", self.__on_window_state_event)
         self.connect("configure-event", self.__on_configure_event)
         self.connect("destroy", self.__on_destroy)
+        self.set_size_request(ArtSize.MINIPLAYER, ArtSize.MINIPLAYER)
         return [
             (App().player, "current-changed", "_on_current_changed")
         ]
@@ -84,9 +85,11 @@ class Window(Handy.ApplicationWindow, SignalsHelper):
             miniplayer.set_vexpand(revealed)
             show_buttons(not revealed)
             if revealed:
+                self.__toolbar.hide()
                 self.__container.hide()
                 emit_signal(self.__container, "can-go-back-changed", False)
             else:
+                self.__toolbar.show()
                 self.__container.show()
                 emit_signal(self.__container, "can-go-back-changed",
                             self.__container.can_go_back)
@@ -104,8 +107,9 @@ class Window(Handy.ApplicationWindow, SignalsHelper):
                 App().lookup_action("miniplayer").change_state(
                     GLib.Variant("b", False))
             else:
-                self.__miniplayer.destroy()
-                self.__miniplayer = None
+                if not self.folded:
+                    self.__miniplayer.destroy()
+                    self.__miniplayer = None
                 self.__container.show()
                 show_buttons(True)
         if self.__miniplayer is not None:
@@ -198,10 +202,7 @@ class Window(Handy.ApplicationWindow, SignalsHelper):
         """
         self.__setup_size_and_position()
         if App().settings.get_value("auto-update") or App().tracks.is_empty():
-            # Delayed, make python segfault on sys.exit() otherwise
-            # No idea why, maybe scanner using Gstpbutils before Gstreamer
-            # initialisation is finished...
-            GLib.timeout_add(1000, App().scanner.update, ScanType.FULL)
+            App().scanner.update(ScanType.FULL)
 
     def __on_button_release_event(self, window, event):
         """
